@@ -21,6 +21,8 @@
 #ifndef _KMPLAYER_ASX_H_
 #define _KMPLAYER_ASX_H_
 
+#include <qstring.h>
+
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -40,44 +42,44 @@ const short id_node_duration = 408;
 /**
  * '<ASX>' tag
  */
-class KMPLAYER_NO_EXPORT Asx : public Mrl {
+class Asx : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Asx (NodePtr & d) : Mrl (d, id_node_asx) {}
-    Node *childFromTag (const String & tag);
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "ASX"; }
-    bool expose () const { return !title.isEmpty (); }
-    PlayType playType ();
+    bool expose () const { return !pretty_name.isEmpty (); }
+    /**
+     * True if no mrl children
+     */
+    bool isPlayable ();
 };
 
 /**
  * Entry tag as found in ASX for playlist item
  */
-class Entry : public Mrl {
+class KMPLAYER_NO_EXPORT Entry : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Entry (NodePtr & d)
-        : Mrl (d, id_node_entry), duration_timer (NULL), ref_child_count (0) {}
-    Node *childFromTag (const String & tag);
-    void *message (MessageType msg, void *content=NULL);
+        : Mrl (d, id_node_entry), ref_child_count (0) {}
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "Entry"; }
     /**
      * False, but since we might have a 'base' child, we can have a rel. src
      */
-    PlayType playType ();
+    bool isPlayable ();
     void activate ();
     void deactivate ();
     bool expose () const;
-
-    Command *duration_timer;
     int ref_child_count;
 };
 
 /**
  * Ref tag as found in ASX for URL item in playlist item
  */
-class Ref : public Mrl {
+class KMPLAYER_NO_EXPORT Ref : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Ref (NodePtr & d) : Mrl (d, id_node_ref) {}
-    //Node *childFromTag (const String & tag);
+    //NodePtr childFromTag (const QString & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "Ref"; }
     bool expose () const;
@@ -86,10 +88,10 @@ public:
 /**
  * EntryRef tag as found in ASX for shortcut of Entry plus Ref playlist item
  */
-class EntryRef : public Mrl {
+class KMPLAYER_NO_EXPORT EntryRef : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT EntryRef (NodePtr & d) : Mrl (d, id_node_entryref) {}
-    //Node *childFromTag (const String & tag);
+    //NodePtr childFromTag (const QString & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "EntryRef"; }
 };
