@@ -21,6 +21,8 @@
 #ifndef _KMPLAYER_ATOM_H_
 #define _KMPLAYER_ATOM_H_
 
+#include <qstringlist.h>
+
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -33,34 +35,25 @@ const short id_node_link = 302;
 const short id_node_title = 303;
 const short id_node_summary = 304;
 const short id_node_content = 305;
-const short id_node_media_group = 306;
-const short id_node_media_content = 307;
-const short id_node_media_title = 308;
-const short id_node_media_description = 309;
-const short id_node_media_player = 310;
-const short id_node_media_thumbnail = 311;
-const short id_node_gd_rating = 312;
-const short id_node_ignored = 313;
 
 /**
  * '<feed>' tag
  */
-class KMPLAYER_NO_EXPORT Feed : public Mrl {
+class Feed : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Feed (NodePtr & d) : Mrl (d, id_node_feed) {}
-    Node *childFromTag (const String & tag);
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "feed"; }
     void closed ();
-    bool expose () const { return !title.isEmpty (); }
+    bool expose () const { return !pretty_name.isEmpty (); }
 };
 
 class KMPLAYER_NO_EXPORT Entry : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Entry (NodePtr & d) : Mrl (d, id_node_entry) {}
-    Node *childFromTag (const String & tag);
-    String description () const;
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "entry"; }
-    PlayType playType () { return play_type_none; }
+    bool isPlayable () { return false; }
     void closed ();
 };
 
@@ -68,8 +61,7 @@ class KMPLAYER_NO_EXPORT Link : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Link (NodePtr & d) : Mrl (d, id_node_link) {}
     KDE_NO_EXPORT const char * nodeName () const { return "link"; }
-    PlayType playType ();
-    bool expose () const { return !src.isEmpty (); }
+    bool isPlayable () { return !src.isEmpty (); }
     void closed ();
 };
 
@@ -77,27 +69,9 @@ class KMPLAYER_NO_EXPORT Content : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Content (NodePtr &d) : Mrl(d, id_node_content) {}
     KDE_NO_EXPORT const char * nodeName () const { return "content"; }
-    PlayType playType ();
-    void closed ();
-    bool expose () const { return !src.isEmpty (); }
-};
-
-class KMPLAYER_NO_EXPORT MediaGroup : public Title {
-public:
-    MediaGroup (NodePtr &d) : Title (d, id_node_media_group) {}
-    Node *childFromTag (const String &tag);
-    void *message (MessageType msg, void *content=NULL);
-    KDE_NO_EXPORT const char *nodeName () const { return "media:group"; }
-    bool expose () const { return false; }
-    void addSummary (Node *ratings);
-};
-
-class KMPLAYER_NO_EXPORT MediaContent : public Mrl {
-public:
-    MediaContent (NodePtr &d) : Mrl (d, id_node_media_content) {}
-    KDE_NO_EXPORT const char *nodeName () const { return "media:content"; }
-    PlayType playType ();
+    bool isPlayable ();
     void closed ();
+    //bool expose () const { return isPlayable (); }
 };
 
 } //namespace ATOM
