@@ -21,6 +21,8 @@
 #ifndef _KMPLAYER_RSS_H_
 #define _KMPLAYER_RSS_H_
 
+#include <qstring.h>
+
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -33,45 +35,37 @@ const short id_node_item = 202;
 const short id_node_title = 203;
 const short id_node_description = 204;
 const short id_node_enclosure = 205;
-const short id_node_category = 206;
-const short id_node_ignored = 207;
 
 /**
  * '<RSS>' tag
  */
-class KMPLAYER_NO_EXPORT Rss : public Mrl {
+class Rss : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Rss (NodePtr & d) : Mrl (d, id_node_rss) {}
-    Node *childFromTag (const String & tag);
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "rss"; }
     bool expose () const { return false; }
 };
-
-class KMPLAYER_NO_EXPORT Channel : public Title {
+    
+class KMPLAYER_NO_EXPORT Channel : public Mrl {
 public:
-    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Title (d, id_node_channel) {}
-    Node *childFromTag (const String & tag);
+    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Mrl (d, id_node_channel) {}
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "channel"; }
-    PlayType playType () { return play_type_none; }
+    bool isPlayable () { return false; }
     void closed ();
     bool expose () const;
 };
 
 class KMPLAYER_NO_EXPORT Item : public Mrl {
 public:
-    KDE_NO_CDTOR_EXPORT Item (NodePtr & d)
-        : Mrl (d, id_node_item), timer (NULL) {}
-    Node *childFromTag (const String & tag);
-    String description () const;
+    KDE_NO_CDTOR_EXPORT Item (NodePtr & d) : Mrl (d, id_node_item) {}
+    NodePtr childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "item"; }
-    PlayType playType () { return cached_play_type; }
-    Mrl * linkNode ();
+    bool isPlayable () { return !src.isEmpty (); }
     void closed ();
     void activate ();
     void deactivate ();
-    void *message (MessageType msg, void *content=NULL);
-    NodePtrW enclosure;
-    Command *timer;
 };
 
 class KMPLAYER_NO_EXPORT Enclosure : public Mrl {
