@@ -17,15 +17,16 @@
  **/
 
 #include <config.h>
-#include <string.h>
+#include <kdebug.h>
+#include <kurl.h>
 
 #include "kmplayer_xspf.h"
 
 using namespace KMPlayer;
 
 
-KDE_NO_EXPORT Node *XSPF::Playlist::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT NodePtr XSPF::Playlist::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "tracklist"))
         return new Tracklist (m_doc);
     else if (!strcasecmp (name, "creator"))
@@ -54,34 +55,33 @@ KDE_NO_EXPORT Node *XSPF::Playlist::childFromTag (const String & tag) {
         return new DarkNode (m_doc, name, id_node_meta);
     else if (!strcasecmp (name, "extension"))
         return new DarkNode (m_doc, name, id_node_extension);
-    return NULL;
+    return 0L;
 }
 
 KDE_NO_EXPORT void XSPF::Playlist::closed () {
-    for (Node *e = firstChild (); e; e = e->nextSibling ()) {
+    for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
         if (e->id == id_node_title)
-            title = e->innerText ().stripWhiteSpace ();
+            pretty_name = e->innerText ().simplifyWhiteSpace ();
         else if (e->id == id_node_location)
             src = e->innerText ().stripWhiteSpace ();
     }
-    Mrl::closed ();
 }
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_EXPORT Node *XSPF::Tracklist::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT NodePtr XSPF::Tracklist::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "track"))
         return new XSPF::Track (m_doc);
-    return NULL;
+    return 0L;
 }
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_EXPORT Node *XSPF::Track::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT NodePtr XSPF::Track::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "location"))
-        return new Location (m_doc);
+        return new DarkNode (m_doc, name, id_node_location);
     else if (!strcasecmp (name, "creator"))
         return new DarkNode (m_doc, name, id_node_creator);
     else if (!strcasecmp (name, "title"))
@@ -106,47 +106,29 @@ KDE_NO_EXPORT Node *XSPF::Track::childFromTag (const String & tag) {
         return new DarkNode (m_doc, name, id_node_meta);
     else if (!strcasecmp (name, "extension"))
         return new DarkNode (m_doc, name, id_node_extension);
-    return NULL;
+    return 0L;
 }
 
 KDE_NO_EXPORT void XSPF::Track::closed () {
-    for (Node *e = firstChild (); e; e = e->nextSibling ()) {
+    for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
         switch (e->id) {
             case id_node_title:
-                title = e->innerText ().stripWhiteSpace ();
+                pretty_name = e->innerText ();
                 break;
             case id_node_location:
-                location = e;
-                src = e->mrl ()->src;
+                src = e->innerText ().stripWhiteSpace ();
                 break;
         }
     }
-    Mrl::closed ();
 }
 
 KDE_NO_EXPORT void XSPF::Track::activate () {
-    for (Node *e = firstChild (); e; e = e->nextSibling ())
+    for (NodePtr e = firstChild (); e; e = e->nextSibling ())
         if (e->id == id_node_annotation) {
-            String inf = e->innerText ().stripWhiteSpace ();
-            document ()->message (MsgInfoString, &inf);
+            PlayListNotify * n = document ()->notify_listener;
+            if (n)
+                n->setInfoMessage (e->innerText ().stripWhiteSpace ());
             break;
         }
     Mrl::activate ();
 }
-
-KDE_NO_EXPORT Node::PlayType XSPF::Track::playType () {
-    if (location)
-        return location->playType ();
-    return Mrl::playType ();
-}
-
-KDE_NO_EXPORT Mrl * XSPF::Track::linkNode () {
-    if (location)
-        return location->mrl ();
-    return Mrl::linkNode ();
-}
-
-void XSPF::Location::closed () {
-    src = innerText ().stripWhiteSpace ();
-    Mrl::closed ();
-}
